"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateCoverageSummary = exports.createComment = exports.getIssueNumber = exports.generateComment = exports.getCoveragePercent = exports.execCommand = exports.summaryFormatter = exports.stringFormatter = void 0;
const exec_1 = require("@actions/exec");
const github_1 = require("@actions/github");
const core_1 = require("@actions/core");
exports.stringFormatter = (input) => input.join('\n');
exports.summaryFormatter = (input) => exports.stringFormatter(input.slice(1, input.length - 1));
exports.execCommand = (command, formatter = exports.stringFormatter) => __awaiter(void 0, void 0, void 0, function* () {
    const output = [];
    const options = {
        silent: true,
        listeners: {
            stdline: (data) => {
                output.push(data);
            }
        }
    };
    yield exec_1.exec(command, [], options);
    return Promise.resolve(formatter(output));
});
exports.getCoveragePercent = () => __awaiter(void 0, void 0, void 0, function* () {
    const percent = yield exports.execCommand('npx coverage-percentage ./coverage/lcov.info --lcov');
    return Number(parseFloat(percent).toFixed(2));
});
exports.generateComment = (percent, summary) => `<p>Total Coverage: <code>${percent}</code></p>
<details><summary>Coverage report</summary>

${summary}

</details>`;
exports.getIssueNumber = (payload) => {
    var _a, _b;
    return ((_a = payload === null || payload === void 0 ? void 0 : payload.pull_request) === null || _a === void 0 ? void 0 : _a.number) || ((_b = payload === null || payload === void 0 ? void 0 : payload.issue) === null || _b === void 0 ? void 0 : _b.number);
};
exports.createComment = (comment) => __awaiter(void 0, void 0, void 0, function* () {
    const octokit = github_1.getOctokit(core_1.getInput('github-token'));
    const issueNumber = exports.getIssueNumber(github_1.context.payload);
    if (!issueNumber) {
        console.log('CONTEXT', github_1.context);
        core_1.warning('Issue number not found. Impossible to create a comment');
        return;
    }
    yield octokit.issues.createComment({
        repo: github_1.context.repo.repo,
        owner: github_1.context.repo.owner,
        body: comment,
        issue_number: issueNumber
    });
});
exports.generateCoverageSummary = (jestCommand) => __awaiter(void 0, void 0, void 0, function* () { return yield exports.execCommand(jestCommand, exports.summaryFormatter); });
